@@ -1,30 +1,23 @@
 #' define_prior
 #'
-#' Generates prior model objects to pass to brms
+#' Generates prior model objects to pass to \pkg{brms}
 #'
 #' @inheritParams bnec
 #'
+#' @param family A \code{\link[stats]{family}} function.
 #' @param predictor The predictor variable for the NEC model fit.
 #' @param response The response variable for the NEC model fit.
 #'
-#' @return A \code{\link[base]{list}} containing the \code{\link[brms]{prior}}
-#' and the string defining response distribution family to use.
+#' @return An object of class \code{\link[brms]{brmsprior}}.
 #' @importFrom brms bf prior_string negbinomial Beta
 #' @importFrom stats qlogis binomial quantile Gamma poisson gaussian sd
+#'
+#' @noRd
 define_prior <- function(model, family, predictor, response) {
   link_tag <- family$link
   custom_name <- check_custom_name(family)
   if (link_tag %in% c("logit", "log")) {
     fam_tag <- "gaussian"
-    if (custom_name == "beta_binomial2") {
-      response <- binomial(link = link_tag)$linkfun(response)
-    } else {
-      if (family$family == "binomial") {
-        response <- linear_rescale(response, r_out = c(0.001, 0.999))
-      }
-      response <- family$linkfun(response)
-    }
-    response <- response[is.finite(response)]
   } else {
     if (custom_name == "beta_binomial2") {
       fam_tag <- custom_name
@@ -32,11 +25,13 @@ define_prior <- function(model, family, predictor, response) {
       fam_tag <- family$family
     }
   }
-  if (length(response) == 0) {
-    stop("response vector is empty, most likely caused by Inf values",
-         " on the inverse link scale (i.e. 0 or 1 data) or for containing NAs",
-         " only")
+  if (custom_name == "beta_binomial2" || family$family == "binomial") {
+    if (is.integer(response) || max(response) > 1) {
+      stop("Response vector must be passed as a proportion to define_prior",
+           " (not as integers) for the binomial and beta_binomial2 families.")
+    }
   }
+  response <- response_link_scale(response, family)
   x_type <- set_distribution(predictor)
   u_t_g <- paste0("gamma(2, ",
                   1 / (quantile(response, probs = 0.75) / 2),
@@ -51,6 +46,7 @@ define_prior <- function(model, family, predictor, response) {
                gaussian = paste0("normal(",
                                  quantile(response, probs = 0.9),
                                  ", ", sd(response) * 2.5, ")"),
+               bernoulli = "beta(5, 1)",
                binomial = "beta(5, 1)",
                beta_binomial2 = "beta(5, 1)",
                beta = "beta(5, 1)")
@@ -60,6 +56,7 @@ define_prior <- function(model, family, predictor, response) {
                gaussian = paste0("normal(",
                                  quantile(response, probs = 0.1),
                                  ", ", sd(response) * 2.5, ")"),
+               bernoulli = "beta(1, 5)",
                binomial = "beta(1, 5)",
                beta_binomial2 = "beta(1, 5)",
                beta = "beta(1, 5)")
@@ -73,9 +70,9 @@ define_prior <- function(model, family, predictor, response) {
                                         probs = 0.5),
                                ", ", sd(predictor) * 2.5, ")"))
   lbs <- c(Gamma = 0, poisson = 0, negbinomial = 0, gaussian = NA,
-           binomial = 0, beta_binomial2 = 0, beta = 0)
+           bernoulli = 0, binomial = 0, beta_binomial2 = 0, beta = 0)
   ubs <- c(Gamma = NA, poisson = NA, negbinomial = NA, gaussian = NA,
-           binomial = 1, beta_binomial2 = 1, beta = 1)
+           bernoulli = 1, binomial = 1, beta_binomial2 = 1, beta = 1)
   # y-dependent priors
   pr_top <- prior_string(y_t_prs[fam_tag], nlpar = "top",
                          lb = lbs[fam_tag], ub = ubs[fam_tag])
@@ -88,12 +85,10 @@ define_prior <- function(model, family, predictor, response) {
   pr_ec50 <- prior_string(x_prs[x_type], nlpar = "ec50",
                           lb = min(predictor), ub = max(predictor))
   # x- and y-independent priors
-
   pr_d <- prior_string("normal(0, 2)", nlpar = "d")
   pr_beta <- prior_string("normal(0, 2)", nlpar = "beta")
   pr_f <- prior_string("normal(0, 2)", nlpar = "f")
   pr_slope <- prior_string("normal(0, 2)", nlpar = "slope")
-
   # assemble
   if (model == "ecxsigm") {
     priors <- pr_beta + pr_top + pr_d
